##  Managing Relation Mappings
You can manage relation mappings on the integration configuration page.
  * Edit a mapping: Hover over a mapping, choose Configure, then adjust the parameters you need.
  * Activate or deactivate a mapping: Use the toggle on the left to activate or deactivate a mapping.
  * Delete a mapping: Hover over a mapping, then choose Delete Mapping on the right. Deleting a relation mapping does not delete synchronized relationships. Existing relations remain in both systems.
